BuiltInProperties class

Represent the document properties in a MS Excel Document.

Constructors

BuiltInProperties()

Properties

author ↔ String?
Gets or Sets author of the document.
getter/setter pair
category ↔ String?
Gets or Sets category of the document.
getter/setter pair
comments ↔ String?
Gets or Sets comments of the document.
getter/setter pair
company ↔ String?
Gets or Sets company of the document.
getter/setter pair
createdDate ↔ DateTime?
Gets or Sets creation date of the document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manager ↔ String?
Gets or Sets manager of the document.
getter/setter pair
modifiedDate ↔ DateTime?
Gets or Sets modified date of the document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Gets or Sets status of the document.
getter/setter pair
subject ↔ String?
Gets or Sets subject of the document.
getter/setter pair
tags ↔ String?
Gets or Sets tags of the document.
getter/setter pair
title ↔ String?
Gets or Sets title of the document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited